==> kde4libs_3.80.1.orig.tar.gz: kde4libs-3.80.1/kdeprint/management/networkscanner.h <==
/*
 *  This file is part of the KDE libraries
 *  Copyright (c) 2001-2002 Michael Goffioul <kdeprint@swing.be>
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public
 *  License version 2 as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public License
 *  along with this library; see the file COPYING.LIB.  If not, write to
 *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 *  Boston, MA 02110-1301, USA.
 **/

#ifndef NETWORKSCANNER_H
#define NETWORKSCANNER_H

#include <kdialog.h>

#include <QList>
#include <QWidget>

namespace KNetwork { class KResolverEntry; }


class KDEPRINT_MANAGEMENT_EXPORT NetworkScanner : public QWidget
{
	Q_OBJECT

public:
	NetworkScanner( int port = 9100, QWidget *parent = 0 );
	~NetworkScanner();

	struct SocketInfo
	{
		QString IP;
		QString Name;
		int Port;
	};

	QList<NetworkScanner::SocketInfo*> printerList() const;

	int timeout() const;
	void setTimeout( int to );
	QString subnet() const;
	void setSubnet( const QString& );
	int port() const;
	void setPort( int );
	bool checkPrinter( const QString&, int );

Q_SIGNALS:
	void scanStarted();
	void scanFinished();

protected Q_SLOTS:
	void slotConnectionSuccess( const KNetwork::KResolverEntry& );
	void slotConnectionFailed( int );
	void slotTimeout();
	void slotScanClicked();
	void slotSettingsClicked();
	void slotNext();

protected:
	void next();
	void finish();
	void start();

private:
	class NetworkScannerPrivate;
	NetworkScannerPrivate* const d;
};

class QLineEdit;
class QComboBox;

class NetworkScannerConfig : public KDialog
{
	Q_OBJECT

public:
	NetworkScannerConfig(NetworkScanner *scanner, const char *name = 0);
	~NetworkScannerConfig();

protected Q_SLOTS:
	void slotOk();

private:
	QLineEdit	*mask_, *tout_;
	QComboBox	*port_;
	NetworkScanner *scanner_;
};

#endif

==> kde4libs_3.93.0.orig.tar.gz: kde4libs-3.93.0.orig/kdeprint/management/networkscanner.h <==
/*
 *  This file is part of the KDE libraries
 *  Copyright (c) 2001-2002 Michael Goffioul <kdeprint@swing.be>
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public
 *  License version 2 as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public License
 *  along with this library; see the file COPYING.LIB.  If not, write to
 *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 *  Boston, MA 02110-1301, USA.
 **/

#ifndef NETWORKSCANNER_H
#define NETWORKSCANNER_H

#include <kdialog.h>
#include <kdeprint_export.h>

#include <QtCore/QList>
#include <QtGui/QWidget>
#include <QtNetwork/QAbstractSocket>

class KDEPRINT_MANAGEMENT_EXPORT NetworkScanner : public QWidget
{
	Q_OBJECT

public:
	explicit NetworkScanner( int port = 9100, QWidget *parent = 0 );
	~NetworkScanner();

	struct SocketInfo
	{
		QString IP;
		QString Name;
		int Port;
	};

	QList<NetworkScanner::SocketInfo*> printerList() const;

	int timeout() const;
	void setTimeout( int to );
	QString subnet() const;
	void setSubnet( const QString& );
	int port() const;
	void setPort( int );
	bool checkPrinter( const QString&, int );

Q_SIGNALS:
	void scanStarted();
	void scanFinished();

protected Q_SLOTS:
	void slotConnectionSuccess();
	void slotConnectionFailed();
	void slotTimeout();
	void slotScanClicked();
	void slotSettingsClicked();
	void slotNext();

protected:
	void next();
	void finish();
	void start();

private:
	class NetworkScannerPrivate;
	NetworkScannerPrivate* const d;
};

class QLineEdit;
class QComboBox;

class NetworkScannerConfig : public KDialog
{
	Q_OBJECT

public:
	explicit NetworkScannerConfig(NetworkScanner *scanner, const char *name = 0);
	~NetworkScannerConfig();

protected Q_SLOTS:
	void slotOk();

private:
	QLineEdit	*mask_, *tout_;
	QComboBox	*port_;
	NetworkScanner *scanner_;
};

#endif
